<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * exacomp block rendrer
 *
 * @package    block_exacomp
 * @copyright  2013 gtn gmbh
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
defined('MOODLE_INTERNAL') || die;

class block_exacomp_renderer extends plugin_renderer_base {

	public function print_header(){
		$content = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN">';
		$content .= html_writer::start_tag('html');
		$content .= html_writer::start_tag('head');
		$content .= html_writer::start_tag('title');
		$content .= get_string('studenttabcompetencesagenda', 'block_exacomp');
		$content .= html_writer::end_tag('title');
		$content .= html_writer::empty_tag('meta', array('http-equiv'=>'Content Type', 'content'=>'text/html', 'charset'=>'utf-8'));
		$content .= html_writer::empty_tag('link', array('rel'=>'stylesheet', 'type'=>'text/css', 'href'=>'styles.css'));
		$content .= html_writer::end_tag('head');
		$content .= html_writer::start_tag('body');

		return $content;
	}
	public function print_footer(){
		$content = html_writer::end_tag('body');
		$content .= html_writer::end_tag('html');

		return $content;
	}
	public function form_week_learningagenda($selectstudent,$action,$studentid, $view){
		global $COURSE, $CFG;

		if($view == 0){
			$content = html_writer::start_tag('div',array('style'=>'width:400px;'));
			$content.=$selectstudent;
			$content .= html_writer::start_tag('form', array('id'=>"calendar", 'method'=>"POST", 'action'=>new moodle_url('/blocks/exacomp/learningagenda.php?courseid='.$COURSE->id)));
			$content .= html_writer::start_tag('a', array('href' => new moodle_url('/blocks/exacomp/learningagenda.php?courseid='.$COURSE->id.'&studentid='.$studentid.'&action='.($action-1))));
			$content .= html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/bwd_16x16.png', 'alt' => 'bwd', 'height' => '16', 'width'=>'16'));
			$content .= ' ';
			$content .= html_writer::end_tag('a');
			$content .= html_writer::start_tag('input', array('id'=>"calendarinput", 'class'=>"datepicker", 'type'=>"text", 'name'=>"calendarinput",
					'onchange'=>"this.form.submit();", 'readonly'));
			$content .= html_writer::end_tag('input');
			$content .= ' ';
			$content .= html_writer::start_tag('a', array('href' => new moodle_url('/blocks/exacomp/learningagenda.php?courseid='.$COURSE->id.'&studentid='.$studentid.'&action='.($action+1))));
			$content .= html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/fwd_16x16.png', 'alt' => 'fwd', 'height' => '16', 'width'=>'16'));
			$content .= html_writer::end_tag('a');
			$content .= html_writer::end_tag('div');
			$content .= html_writer::end_tag('form');

			$content .= html_writer::start_tag('div', array('align'=>"right"));
			$content .= html_writer::start_tag('a', array('href' => new moodle_url('/blocks/exacomp/learningagenda.php?courseid='.$COURSE->id.'&studentid='.$studentid.'&druck=1&action='.$action)));
			$content .= html_writer::empty_tag('img', array('src'=>$CFG->wwwroot . '/blocks/exacomp/pix/view_print.png', 'alt'=>'print'));
			$content .= html_writer::end_tag('a');
			$content .= html_writer::end_tag('div');
		} else {
			$content = html_writer::start_tag('div', array('id'=>'linkback', 'align'=>"right"));
			$content .= html_writer::start_tag('a', array('href' => new moodle_url('/blocks/exacomp/learningagenda.php?courseid='.$COURSE->id.'&studentid='.$studentid.'&druck=0&action='.$action)));
			$content .= html_writer::tag('p',"Zurück zur Originalansicht");
			$content .= html_writer::end_tag('a');
			$content .= html_writer::end_tag('div');
		}

		return $content;
	}
	public function render_learning_agenda($data, $wochentage){
		global $CFG, $COURSE;

		//header
		$table = new html_table();
		$table->attributes['class'] = 'lernagenda';
		$table->border = 3;
		$head = array();

		$cellhead1 = new html_table_cell();
		$cellhead1->text = html_writer::tag("p", get_string('plan', 'block_exacomp'));
		$cellhead1->colspan = 4;
		$head[] = $cellhead1;

		$cellhead2 = new html_table_cell();
		$cellhead2->text = html_writer::tag("p", get_string('assessment', 'block_exacomp'));
		$cellhead2->colspan = 2;
		$head[] = $cellhead2;

		$table->head = $head;

		$rows = array();

		//erste Reihe->Überschriften
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = "";
		$cell->colspan = 2;
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('todo', 'block_exacomp'));
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('learning', 'block_exacomp'));
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('student', 'block_exacomp'));
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('teacher', 'block_exacomp'));
		$row->cells[] = $cell;

		$rows[] = $row;

		foreach($data as $day=>$daydata){
			$row = new html_table_row();
			$cell = new html_table_cell();
			$cell->text = html_writer::tag("p", $day.": ".$daydata['date']);

			$cell->rowspan = count($daydata, COUNT_RECURSIVE)-count($daydata);
			$row->cells[] = $cell;

			foreach($daydata as $subject=>$subjectdata){

				if(strcmp($subject,'date')!=0){
					if(strcmp($subject, 'no example available')!=0){
						$cell = new html_table_cell();
						$cell->text = html_writer::tag("p",$subject);
						$cell->rowspan = count($subjectdata);

						$row->cells[] = $cell;
						foreach($subjectdata as $example){
							$cell = new html_table_cell();
							$cell->text = html_writer::tag("p", html_writer::tag("b", $example->desc.": ").$example->numb." ".$example->title." (".$example->cat.")");
							$row->cells[] = $cell;

							$cell = new html_table_cell();
							$cell->text = html_writer::tag("p", "");
							$row->cells[] = $cell;

							$cell = new html_table_cell();
							if($example->evaluate == 1){
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/ok_16x16.png', 'alt' => '1', 'height' => '16', 'width'=>'16'));
							}

							else{
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/del_16x16.png', 'alt' => '0', 'height' => '16', 'width'=>'16'));
							}
							$row->cells[] = $cell;

							$cell = new html_table_cell();
							if($example->tevaluate == 1){
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/ok_16x16.png', 'alt' => '1', 'height' => '16', 'width'=>'16'));
							}

							else{
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/del_16x16.png', 'alt' => '0', 'height' => '16', 'width'=>'16'));
							}
							$row->cells[] = $cell;

							$rows[] = $row;
							$row = new html_table_row();
						}
					}else{
						$cell = new html_table_cell();
						$cell->text = html_writer::tag("p",get_string('no_example', 'block_exacomp'));
						$cell->colspan = 5;
						$row->cells[] = $cell;
						$rows[] = $row;
						$row = new html_table_row();
					}
				}
			}

		}

		$table->data = $rows;

		return html_writer::tag("div", html_writer::table($table), array("id"=>"exabis_competences_block"));
	}

	public function print_view_learning_agenda($data, $studentname){
		global $CFG, $COURSE;

		//$content = html_writer::tag('p', "Schülerinformation");

		//header
		$table = new html_table();
		$table->attributes['class'] = 'lernagenda';
		$table->border = 3;
		$head = array();

		$cellhead1 = new html_table_cell();
		$cellhead1->text = html_writer::tag("p", get_string('plan', 'block_exacomp').
				get_string('von', 'block_exacomp').$studentname.get_string('vom', 'block_exacomp').
				$data[get_string('MO', 'block_exacomp')]['date'].get_string('bis', 'block_exacomp').$data[get_string('FR', 'block_exacomp')]['date']);
		$cellhead1->colspan = 4;
		$head[] = $cellhead1;

		$cellhead2 = new html_table_cell();
		$cellhead2->text = html_writer::tag("p", get_string('assessment', 'block_exacomp'));
		$cellhead2->colspan = 2;
		$head[] = $cellhead2;

		$table->head = $head;

		$rows = array();

		//erste Reihe->Überschriften
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = "";
		$cell->colspan = 2;
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('todo', 'block_exacomp'));
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('learning', 'block_exacomp'));
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('student', 'block_exacomp'));
		$row->cells[] = $cell;

		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p", get_string('teacher', 'block_exacomp'));
		$row->cells[] = $cell;

		$rows[] = $row;

		foreach($data as $day=>$daydata){
			$row = new html_table_row();
			$cell = new html_table_cell();
			$cell->text = html_writer::tag("p", $day);

			$cell->rowspan = count($daydata, COUNT_RECURSIVE)-count($daydata);
			$row->cells[] = $cell;

			foreach($daydata as $subject=>$subjectdata){
				if(strcmp($subject,'date')!=0){
					if(strcmp($subject, 'no example available')!=0){
						$cell = new html_table_cell();
						$cell->text = html_writer::tag("p",$subject);
						$cell->rowspan = count($subjectdata);

						$row->cells[] = $cell;
						foreach($subjectdata as $example){
							$cell = new html_table_cell();
							$cell->text = html_writer::tag("p", html_writer::tag("b", $example->desc.": ").$example->numb." ".$example->title." (".$example->cat.")");
							$row->cells[] = $cell;

							$cell = new html_table_cell();
							$cell->text = html_writer::tag("p", "");
							$row->cells[] = $cell;

							$cell = new html_table_cell();
							if($example->evaluate == 1){
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/ok_16x16.png', 'alt' => '1', 'height' => '16', 'width'=>'16'));
							}
							else{
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/del_16x16.png', 'alt' => '0', 'height' => '16', 'width'=>'16'));
							}
							$row->cells[] = $cell;

							$cell = new html_table_cell();
							if($example->tevaluate == 1){
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/ok_16x16.png', 'alt' => '1', 'height' => '16', 'width'=>'16'));
							}
							else{
								$cell->text = html_writer::empty_tag('img', array('src' => $CFG->wwwroot . '/blocks/exacomp/pix/del_16x16.png', 'alt' => '0', 'height' => '16', 'width'=>'16'));
							}
							$row->cells[] = $cell;

							$rows[] = $row;
							$row = new html_table_row();
						}
					}else{
						$cell = new html_table_cell();
						$cell->text = html_writer::tag("p",get_string('no_example', 'block_exacomp'));
						$cell->colspan = 5;
						$row->cells[] = $cell;
						$rows[] = $row;
						$row = new html_table_row();
					}
				}
			}
		}

		$table->data = $rows;

		$content = html_writer::tag("div", html_writer::table($table), array("id"=>"exabis_competences_block"));
		return $content;
	}
	public function render_tax_competence_grid($niveaus, $subject, $topics, $selection = array(), $courseid = 0) {
		global $CFG;

		$table = new html_table();
		$table->attributes['class'] = 'competence_grid';
		$head = array();
		$head[] = "";
		$head[] = "";
		$head[] = "";
		$head = array_merge($head,$niveaus);
		$table->head = $head;

		// Kompetenzbereich
		$rows = array();
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p","Kompetenzbereich");
		$cell->attributes['class'] = 'skill';
		$cell->rowspan = 6;
		$row->cells[] = $cell;

		$rows[] = $row;

		// Subject-Title
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p",$subject->title);
		$cell->attributes['class'] = 'topic';
		$cell->rowspan = 5;
		$row->cells[] = $cell;

		$rows[] = $row;

		// Topic-Title
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = "";
		$cell->attributes['class'] = '';
		$row->cells[] = $cell;

		foreach($topics as $topic) {
			$cell = new html_table_cell();

			$text = $topic->title;
			if(in_array($topic->id, $selection)) {
				$text = html_writer::link($CFG->wwwroot."/blocks/exacomp/assign_competencies.php?courseid=".$courseid."&subjectid=".$subject->id."&topicid=".$topic->id, $text);
			}

			$cell->text = html_writer::tag("p",$text);
			$row->cells[] = $cell;
		}
		$rows[] = $row;

		// A Taxonomie
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p","A");
		$cell->attributes['class'] = 'atax';
		$row->cells[] = $cell;

		foreach($topics as $topic) {
			$cell = new html_table_cell();
			$cell->text = html_writer::tag("p",$topic->ataxonomie);
			$cell->attributes['class'] = 'atax';
			$row->cells[] = $cell;
		}
		$rows[] = $row;

		// B Taxonomie
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p","B");
		$cell->attributes['class'] = 'btax';
		$row->cells[] = $cell;

		foreach($topics as $topic) {
			$cell = new html_table_cell();
			$cell->text = html_writer::tag("p",$topic->btaxonomie);
			$row->cells[] = $cell;
			$cell->attributes['class'] = 'btax';
		}
		$rows[] = $row;

		// C Taxonomie
		$row = new html_table_row();
		$cell = new html_table_cell();
		$cell->text = html_writer::tag("p","C");
		$cell->attributes['class'] = 'ctax';
		$row->cells[] = $cell;

		foreach($topics as $topic) {
			$cell = new html_table_cell();
			$cell->text = html_writer::tag("p",$topic->ctaxonomie);
			$row->cells[] = $cell;
			$cell->attributes['class'] = 'ctax';
		}
		$rows[] = $row;
		$table->data = $rows;

		return html_writer::tag("div", html_writer::table($table), array("id"=>"exabis_competences_block"));
	}
	public function render_competence_grid($niveaus, $skills, $topics, $data, $selection = array(), $courseid = 0) {
		global $CFG;

		$headFlag = false;

		$context = get_context_instance(CONTEXT_COURSE, $courseid);

		$table = new html_table();
		$table->attributes['class'] = 'competence_grid';
		$head = array();


		$rows = array();
		if (empty($data)) return get_string('competencegrid_nodata', 'block_exacomp');

		foreach($data as $skillid => $skill) {

			if($skillid) {
				$row = new html_table_row();
				$cell1 = new html_table_cell();
				$cell1->text = html_writer::tag("span",html_writer::tag("span",$skills[$skillid],array('class'=>'rotated-text__inner')),array('class'=>'rotated-text'));
				$cell1->attributes['class'] = 'skill';
				$cell1->rowspan = count($skill)+1;
				$row->cells[] = $cell1;
				//
				$rows[] = $row;

				if(!$headFlag)
					$head[] = "";
			}

			if(!$headFlag) {
				$head[] = "";
				$head = array_merge($head,$niveaus);
				$table->head = $head;
				$headFlag = true;
			}

			foreach($skill as $topicid => $topic) {
				$row = new html_table_row();

				$cell2 = new html_table_cell();
				$cell2->text = html_writer::tag("span",html_writer::tag("span",$topics[$topicid],array('class'=>'rotated-text__inner')),array('class'=>'rotated-text'));
				$cell2->attributes['class'] = 'topic';
				$row->cells[] = $cell2;

				foreach($niveaus as $niveauid => $niveau) {
					if(isset($data[$skillid][$topicid][$niveauid])) {
						$cell = new html_table_cell();
						$compString = "";
						foreach($data[$skillid][$topicid][$niveauid] as $descriptor) {
							$text = $descriptor->title;
							if(in_array($descriptor->id, $selection)) {
								$text = html_writer::link($CFG->wwwroot."/blocks/exacomp/assign_competencies.php?courseid=".$courseid."&subjectid=".$topicid."&topicid=".$descriptor->id, $text);
							}

							if(isset($descriptor->examples)) {
								$text .= '<br/>';
								foreach($descriptor->examples as $example) {
									$img = '<img src="pix/i_11x11.png" alt="Beispiel" />';
									if($example->task)
										$text .= "<a target='_blank' href='".$example->task."'>".$img."</a>";
									if($example->externalurl)
										$text .= "<a target='_blank' href='".$example->externalurl."'>".$img."</a>";
								}
							}
							$compString .= $text;

							if (has_capability('block/exacomp:teacher', $context)) {
								if(isset($descriptor->teachercomp) && in_array($descriptor->id, $selection)) {
									//display checkbox
									$compString .= "<br/>L: ";
									$compString .= html_writer::checkbox("data[".$topicid."][".$descriptor->id."]", 1,$descriptor->teachercomp);
								}

								if(isset($descriptor->studentcomp) && $descriptor->studentcomp)
									$compString .= " S: " . html_writer::checkbox("studentdata[".$topicid."][".$descriptor->id."]", 1,$descriptor->studentcomp,"",array("disabled"=>"disabled"));;
							} /*else {
							if(isset($descriptor->teachercomp) && $descriptor->teachercomp)
								//$compString .= "T";
							$cssClass = "teachercomp";
							}
							//if(isset($descriptor->studentcomp) && $descriptor->studentcomp)
								//	$compString .= "S";
							*/

							if(count($data[$skillid][$topicid][$niveauid]) > 1)
								$compString .= html_writer::tag("hr","");
						}
						$cssClass = (isset($descriptor->teachercomp) && $descriptor->teachercomp) ? "competenceok" : ((isset($descriptor->studentcomp) && $descriptor->studentcomp) ? "competenceyellow" : "");

						$cell->text = $compString;
						$cell->attributes['class'] = $cssClass;
						$row->cells[] = $cell;
					} else
						$row->cells[] = "";
				}
				$rows[] = $row;
			}
			//$rows[] = $row;
		}
		$table->data = $rows;

		return html_writer::tag("div", html_writer::table($table), array("id"=>"exabis_competences_block"));
	}
	public function exacomp_tree(settings_navigation $navigation) {
		$count = 0;
		foreach ($navigation->children as &$child) {
			$child->preceedwithhr = ($count!==0);
			$count++;
		}
		$content = $this->navigation_node($navigation, array('class'=>'block_tree list'));
		if (isset($navigation->id) && !is_numeric($navigation->id) && !empty($content)) {
			$content = $this->output->box($content, 'block_tree_box', $navigation->id);
		}
		return $content;
	}

	protected function navigation_node(navigation_node $node, $attrs=array()) {
		$items = $node->children;

		// exit if empty, we don't want an empty ul element
		if ($items->count()==0) {
			return '';
		}

		// array of nested li elements
		$lis = array();
		foreach ($items as $item) {
			if (!$item->display) {
				continue;
			}

			$isbranch = ($item->children->count()>0  || $item->nodetype==navigation_node::NODETYPE_BRANCH);
			$hasicon = (!$isbranch && $item->icon instanceof renderable);

			if ($isbranch) {
				$item->hideicon = true;
			}
			$content = $this->output->render($item);

			// this applies to the li item which contains all child lists too
			$liclasses = array($item->get_css_type());
			if (!$item->forceopen || (!$item->forceopen && $item->collapse) || ($item->children->count()==0  && $item->nodetype==navigation_node::NODETYPE_BRANCH)) {
				$liclasses[] = 'collapsed';
			}
			if ($isbranch) {
				$liclasses[] = 'contains_branch';
			} else if ($hasicon) {
				$liclasses[] = 'item_with_icon';
			}
			if ($item->isactive === true) {
				$liclasses[] = 'current_branch';
			}
			$liattr = array('class'=>join(' ',$liclasses));
			// class attribute on the div item which only contains the item content
			$divclasses = array('tree_item');
			if ($isbranch) {
				$divclasses[] = 'branch';
			} else {
				$divclasses[] = 'leaf';
			}
			if (!empty($item->classes) && count($item->classes)>0) {
				$divclasses[] = join(' ', $item->classes);
			}
			$divattr = array('class'=>join(' ', $divclasses));
			if (!empty($item->id)) {
				$divattr['id'] = $item->id;
			}
			$content = html_writer::tag('p', $content, $divattr) . $this->navigation_node($item);
			if (!empty($item->preceedwithhr) && $item->preceedwithhr===true) {
				$content = html_writer::empty_tag('hr') . $content;
			}
			$content = html_writer::tag('li', $content, $liattr);
			$lis[] = $content;
		}

		if (count($lis)) {
			return html_writer::tag('ul', implode("\n", $lis), $attrs);
		} else {
			return '';
		}
	}


}